.. _installation_guide:

Installation Guide
==================

Before installing the `vfi` module, you will need `numpy`, `scipy`
and `scikit-learn`

.. code-block:: bash

   pip install numpy scipy scikit-learn

Then, to install `vfi`:

.. code-block:: bash

   pip install vfi

If you wish to install from the source code (available `here <https://github.com/chkoar/vfi>`_ ), change your working directory to the top-level directory of the source code, and issue:

.. code-block:: bash

   python setup.py install
